package com.ruoyi.bst.goods.service.impl;

import com.ruoyi.bst.goods.domain.GoodsQuery;
import com.ruoyi.bst.goods.mapper.GoodsMapper;
import com.ruoyi.bst.goods.service.GoodsValidator;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.mapper.StoreMapper;
import com.ruoyi.bst.store.service.StoreService;
import com.ruoyi.bst.store.service.StoreValidator;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class GoodsValidatorImpl implements GoodsValidator {

    @Autowired
    private StoreService storeService;
    @Autowired
    private StoreMapper storeMapper;
    @Autowired
    private GoodsMapper goodsMapper;

    @Override
    public boolean canEdit(Long goodsId) {
        return canOperate(Arrays.asList(goodsId));
    }

    @Override
    public boolean canDeleteAll(List<Long> goodsIds) {
        return canOperate(goodsIds);
    }

    private boolean hasPermission(List<Long> goodsIds, String permission) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(goodsIds)) {
            return true;
        }
        // 查询运营区
        GoodsQuery query = new GoodsQuery();
        query.setGoodsIds(goodsIds);
        query.setScope(true);
        query.addStorePermission(permission);
        List<Long> goodsIdList = goodsMapper.selectIdByQuery(query);
        return new HashSet<>(goodsIdList).containsAll(goodsIds);
    }

    // 是否可以操作店铺
    private boolean canOperate(List<Long> storeIds) {
        return hasPermission(storeIds, StoreStaffPermission.GOODS_EDIT.getCode());
    }

}

