package com.ruoyi.bst.location.service.impl;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.storage.domain.StorageQuery;
import com.ruoyi.bst.storage.domain.StorageVO;
import com.ruoyi.bst.storage.service.StorageService;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.location.mapper.LocationMapper;
import com.ruoyi.bst.location.domain.Location;
import com.ruoyi.bst.location.domain.LocationVO;
import com.ruoyi.bst.location.domain.LocationQuery;
import com.ruoyi.bst.location.service.LocationService;

/**
 * 存放位置Service业务层处理
 *
 * @author ruoyi
 * @date 2025-06-06
 */
@Service
public class LocationServiceImpl implements LocationService {
    @Autowired
    private LocationMapper locationMapper;
    @Autowired
    private StorageService storageService;

    /**
     * 查询存放位置
     *
     * @param id 存放位置主键
     * @return 存放位置
     */
    @Override
    public LocationVO selectLocationById(Long id, boolean scope) {
        if (id == null) {
            return null;
        }
        LocationQuery query = new LocationQuery();
        query.setId(id);
        query.setScope(scope);
        query.addStorePermission(StoreStaffPermission.LOCATION_VIEW.getCode());
        return this.selectOne(query);
    }

    @Override
    public LocationVO selectOne(LocationQuery query) {
        PageHelper.startPage(1, 1);
        List<LocationVO> list = this.selectLocationList(query);
        return CollectionUtils.firstElement(list);
    }

    /**
     * 查询存放位置列表
     *
     * @param location 存放位置
     * @return 存放位置
     */
    @Override
    public List<LocationVO> selectLocationList(LocationQuery location) {
        return locationMapper.selectLocationList(location);
    }

    /**
     * 新增存放位置
     *
     * @param location 存放位置
     * @return 结果
     */
    @Override
    public int insertLocation(Location location) {
        location.setCreateTime(DateUtils.getNowDate());
        return locationMapper.insertLocation(location);
    }

    /**
     * 修改存放位置
     *
     * @param location 存放位置
     * @return 结果
     */
    @Override
    public int updateLocation(Location location) {
        return locationMapper.updateLocation(location);
    }

    /**
     * 批量删除存放位置
     *
     * @param ids 需要删除的存放位置主键
     * @return 结果
     */
    @Override
    public int deleteLocationByIds(List<Long> ids) {
        StorageQuery query = new StorageQuery();
        query.setLocationIds(ids);
        List<StorageVO> storageList = storageService.selectStorageList(query);
        ServiceUtil.assertion(storageList != null && !storageList.isEmpty(),"当前位置有物品存放,不允许删除");
        return locationMapper.deleteLocationByIds(ids);
    }

    /**
     * 删除存放位置信息
     *
     * @param id 存放位置主键
     * @return 结果
     */
    @Override
    public int deleteLocationById(Long id) {
        return locationMapper.deleteLocationById(id);
    }
}
