package com.ruoyi.bst.location.service.impl;

import com.ruoyi.bst.location.domain.LocationQuery;
import com.ruoyi.bst.location.domain.LocationVO;
import com.ruoyi.bst.location.mapper.LocationMapper;
import com.ruoyi.bst.location.service.LocationValidator;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class LocationValidatorImpl implements LocationValidator {

    @Autowired
    private LocationMapper locationMapper;

    @Override
    public boolean canEdit(Long locationId) {
        return canOperate(Arrays.asList(locationId));
    }

    @Override
    public boolean canDelete(List<Long> locationIds) {
        return canOperate(locationIds);
    }

    private boolean canOperate(List<Long> locationIds) {
        return hasPermission(locationIds, StoreStaffPermission.LOCATION_EDIT.getCode());
    }

    private boolean hasPermission(List<Long> locationIds, String permission) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(locationIds)) {
            return true;
        }
        // 查询拼桌
        LocationQuery query = new LocationQuery();
        query.setLocationIds(locationIds);
        query.setScope(true);
        query.addStorePermission(permission);
        List<Long> locationIdList = locationMapper.selectIdByQuery(query);
        return new HashSet<>(locationIdList).containsAll(locationIds);
    }
}
