package com.ruoyi.bst.sku.mapper;

import java.util.List;
import com.ruoyi.bst.sku.domain.Sku;
import com.ruoyi.bst.sku.domain.SkuVO;
import com.ruoyi.bst.sku.domain.SkuQuery;
import org.apache.ibatis.annotations.Param;
import org.springframework.security.core.parameters.P;

/**
 * 商品SKUMapper接口
 *
 * @author ruoyi
 * @date 2025-05-30
 */
public interface SkuMapper
{
    /**
     * 查询商品SKU
     *
     * @param id 商品SKU主键
     * @return 商品SKU
     */
    SkuVO selectSkuById(Long id);

    /**
     * 查询商品SKU列表
     *
     * @param query 商品SKU
     * @return 商品SKU集合
     */
    List<SkuVO> selectSkuList(@Param("query")SkuQuery query);

    /**
     * 新增商品SKU
     *
     * @param sku 商品SKU
     * @return 结果
     */
    int insertSku(Sku sku);

    /**
     * 批量新增商品SKU
     */
    int batchInsert(@Param("list") List<? extends Sku> list);

    /**
     * 批量修改商品SKU
     */
    int batchUpdate(@Param("list") List<? extends Sku> list);

    /**
     * 修改商品SKU
     *
     * @param sku 商品SKU
     * @return 结果
     */
    public int updateSku(@Param("data") Sku sku);

    /**
     * 删除商品SKU
     *
     * @param id 商品SKU主键
     * @return 结果
     */
    int deleteSkuById(Long id);

    /**
     * 批量删除商品SKU
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSkuByIds(@Param("ids") List<Long> ids);

    int deleteSkuByGoodsIds(@Param("ids") List<Long> ids);
}
