package com.ruoyi.bst.sku.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.sku.mapper.SkuMapper;
import com.ruoyi.bst.sku.domain.Sku;
import com.ruoyi.bst.sku.domain.SkuVO;
import com.ruoyi.bst.sku.domain.SkuQuery;
import com.ruoyi.bst.sku.service.SkuService;

/**
 * 商品SKUService业务层处理
 *
 * @author ruoyi
 * @date 2025-05-30
 */
@Service
public class SkuServiceImpl implements SkuService
{
    @Autowired
    private SkuMapper skuMapper;

    /**
     * 查询商品SKU
     *
     * @param id 商品SKU主键
     * @return 商品SKU
     */
    @Override
    public SkuVO selectSkuById(Long id)
    {
        return skuMapper.selectSkuById(id);
    }

    /**
     * 查询商品SKU列表
     *
     * @param sku 商品SKU
     * @return 商品SKU
     */
    @Override
    public List<SkuVO> selectSkuList(SkuQuery sku)
    {
        return skuMapper.selectSkuList(sku);
    }

    /**
     * 新增商品SKU
     *
     * @param sku 商品SKU
     * @return 结果
     */
    @Override
    public int insertSku(Sku sku)
    {
        return skuMapper.insertSku(sku);
    }

    /**
     * 修改商品SKU
     *
     * @param sku 商品SKU
     * @return 结果
     */
    @Override
    public int updateSku(Sku sku)
    {
        return skuMapper.updateSku(sku);
    }

    /**
     * 批量删除商品SKU
     *
     * @param ids 需要删除的商品SKU主键
     * @return 结果
     */
    @Override
    public int deleteSkuByIds(List<Long> ids)
    {
        return skuMapper.deleteSkuByIds(ids);
    }

    /**
     * 删除商品SKU信息
     *
     * @param id 商品SKU主键
     * @return 结果
     */
    @Override
    public int deleteSkuById(Long id)
    {
        return skuMapper.deleteSkuById(id);
    }

    @Override
    public List<SkuVO> selectListByGoodsId(Long goodsId) {
        if (goodsId == null) {
            return Collections.emptyList();
        }
        SkuQuery query = new SkuQuery();
        query.setGoodsId(goodsId);
        return skuMapper.selectSkuList(query);
    }

    @Override
    public int batchInsert(List<SkuVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return skuMapper.batchInsert(list);
    }

    @Override
    public int batchUpdate(List<? extends SkuVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return skuMapper.batchUpdate(list);
    }

    @Override
    public int batchDelete(List<? extends SkuVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return this.deleteSkuByIds(CollectionUtils.map(list, SkuVO::getId));
    }

    @Override
    public int deleteSkuByGoodsIds(List<Long> ids) {
        return skuMapper.deleteSkuByGoodsIds(ids);
    }
}
