package com.ruoyi.bst.storage.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.location.domain.LocationQuery;
import com.ruoyi.bst.location.domain.LocationVO;
import com.ruoyi.bst.storage.domain.dto.StorageDTO;
import com.ruoyi.bst.storageRecord.domain.StorageRecord;
import com.ruoyi.bst.storageRecord.service.StorageRecordService;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.storage.mapper.StorageMapper;
import com.ruoyi.bst.storage.domain.Storage;
import com.ruoyi.bst.storage.domain.StorageVO;
import com.ruoyi.bst.storage.domain.StorageQuery;
import com.ruoyi.bst.storage.service.StorageService;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * 存酒Service业务层处理
 *
 * @author ruoyi
 * @date 2025-06-06
 */
@Service
public class StorageServiceImpl implements StorageService
{
    @Autowired
    private StorageMapper storageMapper;
    @Autowired
    private TransactionTemplate transactionTemplate;
    @Autowired
    private StorageRecordService storageRecordService;
    @Autowired
    private StorageService storageService;

    /**
     * 查询存酒
     *
     * @param id 存酒主键
     * @return 存酒
     */
    @Override
    public StorageVO selectStorageById(Long id,boolean scope)
    {
        if (id == null) {
            return null;
        }
        StorageQuery query = new StorageQuery();
        query.setId(id);
        query.setScope(scope);
        query.addStorePermission(StoreStaffPermission.STORAGE_VIEW.getCode());
        return this.selectOne(query);
    }


    @Override
    public StorageVO selectOne(StorageQuery query) {
        PageHelper.startPage(1, 1);
        List<StorageVO> list = this.selectStorageList(query);
        return CollectionUtils.firstElement(list);
    }
    /**
     * 查询存酒列表
     *
     * @param storage 存酒
     * @return 存酒
     */
    @Override
    public List<StorageVO> selectStorageList(StorageQuery storage)
    {
        return storageMapper.selectStorageList(storage);
    }

    /**
     * 新增存酒
     *
     * @param storage 存酒
     * @return 结果
     */
    @Override
    public int insertStorage(Storage storage)
    {
        storage.setCreateTime(DateUtils.getNowDate());
        return storageMapper.insertStorage(storage);
    }

    /**
     * 修改存酒
     *
     * @param storage 存酒
     * @return 结果
     */
    @Override
    public int updateStorage(Storage storage)
    {
        return storageMapper.updateStorage(storage);
    }

    /**
     * 批量删除存酒
     *
     * @param ids 需要删除的存酒主键
     * @return 结果
     */
    @Override
    public int deleteStorageByIds(Long[] ids)
    {
        return storageMapper.deleteStorageByIds(ids);
    }

    /**
     * 删除存酒信息
     *
     * @param id 存酒主键
     * @return 结果
     */
    @Override
    public int deleteStorageById(Long id)
    {
        return storageMapper.deleteStorageById(id);
    }

    @Override
    public int storageWine(List<Storage> storageList) {
        storageList.forEach(storage -> {
            storage.setCreateTime(DateUtils.getNowDate());
        });
        return storageMapper.batchInsert(storageList);
    }

    @Override
    public List<StorageVO> selectCurrentNum(StorageQuery query) {
        return storageMapper.selectCurrentNum(query);
    }


    @Override
    public int getWine(List<StorageDTO> list) {
        // 查询需要更新的存酒信息id列表
        List<Long> ids = list.stream()
                .map(StorageDTO::getStorageId)
                .collect(Collectors.toList());

        // 查询出对应的map用于更新数据
        StorageQuery query = new StorageQuery();
        query.setStorageIds(ids);
        Map<Long,Storage> storageMap = storageMapper.selectStorageList(query)
                .stream()
                .collect(Collectors.toMap(Storage::getId,Storage->Storage));

        List<Storage> toStorageUpdate = new ArrayList<>();
        List<StorageRecord> toStorageRecordInsert = new ArrayList<>();

        for (StorageDTO dto : list) {
            Storage storage = storageMap.get(dto.getStorageId());
            if (storage == null) {
                continue;
            }

            // 生成数据用于批量取酒
            StorageVO data = new StorageVO();
            data.setId(storage.getId());
            data.setTakenNum(dto.getNumber());
            toStorageUpdate.add(data);

            // 生成记录
            StorageRecord record = new StorageRecord();
            record.setStorageId(storage.getId());
            record.setStoreId(storage.getStoreId());
            record.setUserId(storage.getUserId());
            record.setReason("用户"+storage.getUserId()+"取酒"+dto.getNumber()+"瓶");
            record.setNumber(dto.getNumber());
            record.setCreateTime(DateUtils.getNowDate());
            toStorageRecordInsert.add(record);
        }


        Integer result = transactionTemplate.execute(status -> {
            // 批量减少数量,根据ID限制
            int i = storageMapper.batchGetWine(toStorageUpdate);
            ServiceUtil.assertion(i != toStorageUpdate.size(),"物品数量不足,取酒失败");
            // 批量插入记录
            i = storageRecordService.batchInsert(toStorageRecordInsert);
            ServiceUtil.assertion(i <= 0,"生成记录失败");
            return i;
        });
        return result == null ? 0 : result;
    }
}
