package com.ruoyi.bst.storage.service.impl;

import com.ruoyi.bst.location.domain.LocationQuery;
import com.ruoyi.bst.location.mapper.LocationMapper;
import com.ruoyi.bst.location.service.LocationValidator;
import com.ruoyi.bst.storage.domain.StorageQuery;
import com.ruoyi.bst.storage.mapper.StorageMapper;
import com.ruoyi.bst.storage.service.StorageValidator;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class StorageValidatorImpl implements StorageValidator {


    private final StorageMapper storageMapper;

    public StorageValidatorImpl(StorageMapper storageMapper) {
        this.storageMapper = storageMapper;
    }

    @Override
    public boolean canEdit(Long storageId) {
        return canOperate(Arrays.asList(storageId));
    }

    @Override
    public boolean canEdit(List<Long> storageIds) {
        return canOperate(storageIds);
    }

    @Override
    public boolean canDelete(List<Long> storageIds) {
        return canOperate(storageIds);
    }

    private boolean canOperate(List<Long> storageIds) {
        return hasPermission(storageIds, StoreStaffPermission.STORAGE_EDIT.getCode());
    }

    private boolean hasPermission(List<Long> storageIds, String permission) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(storageIds)) {
            return true;
        }
        // 查询拼桌
        StorageQuery query = new StorageQuery();
        query.setStorageIds(storageIds);
        query.setScope(true);
        query.addStorePermission(permission);
        List<Long> storageIdList = storageMapper.selectIdByQuery(query);
        return new HashSet<>(storageIdList).containsAll(storageIds);
    }
}
