package com.ruoyi.bst.storageRecord.service.impl;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.storage.domain.StorageQuery;
import com.ruoyi.bst.storage.domain.StorageVO;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.storageRecord.mapper.StorageRecordMapper;
import com.ruoyi.bst.storageRecord.domain.StorageRecord;
import com.ruoyi.bst.storageRecord.domain.StorageRecordVO;
import com.ruoyi.bst.storageRecord.domain.StorageRecordQuery;
import com.ruoyi.bst.storageRecord.service.StorageRecordService;

/**
 * 取酒记录Service业务层处理
 *
 * @author ruoyi
 * @date 2025-06-06
 */
@Service
public class StorageRecordServiceImpl implements StorageRecordService
{
    @Autowired
    private StorageRecordMapper storageRecordMapper;

    /**
     * 查询取酒记录
     *
     * @param id 取酒记录主键
     * @return 取酒记录
     */
    @Override
    public StorageRecordVO selectStorageRecordById(Long id,boolean scope)
    {
        if (id == null) {
            return null;
        }
        StorageRecordQuery query = new StorageRecordQuery();
        query.setId(id);
        query.setScope(scope);
        query.addStorePermission(StoreStaffPermission.STORAGE_RECORD_VIEW.getCode());
        return this.selectOne(query);
    }

    @Override
    public StorageRecordVO selectOne(StorageRecordQuery query) {
        PageHelper.startPage(1, 1);
        List<StorageRecordVO> list = this.selectStorageRecordList(query);
        return CollectionUtils.firstElement(list);
    }

    /**
     * 查询取酒记录列表
     *
     * @param storageRecord 取酒记录
     * @return 取酒记录
     */
    @Override
    public List<StorageRecordVO> selectStorageRecordList(StorageRecordQuery storageRecord)
    {
        return storageRecordMapper.selectStorageRecordList(storageRecord);
    }

    /**
     * 新增取酒记录
     *
     * @param storageRecord 取酒记录
     * @return 结果
     */
    @Override
    public int insertStorageRecord(StorageRecord storageRecord)
    {
        storageRecord.setCreateTime(DateUtils.getNowDate());
        return storageRecordMapper.insertStorageRecord(storageRecord);
    }

    /**
     * 修改取酒记录
     *
     * @param storageRecord 取酒记录
     * @return 结果
     */
    @Override
    public int updateStorageRecord(StorageRecord storageRecord)
    {
        return storageRecordMapper.updateStorageRecord(storageRecord);
    }

    /**
     * 批量删除取酒记录
     *
     * @param ids 需要删除的取酒记录主键
     * @return 结果
     */
    @Override
    public int deleteStorageRecordByIds(Long[] ids)
    {
        return storageRecordMapper.deleteStorageRecordByIds(ids);
    }

    /**
     * 删除取酒记录信息
     *
     * @param id 取酒记录主键
     * @return 结果
     */
    @Override
    public int deleteStorageRecordById(Long id)
    {
        return storageRecordMapper.deleteStorageRecordById(id);
    }

    @Override
    public int batchInsert(List<StorageRecord> storageRecordList) {
        return storageRecordMapper.batchInsert(storageRecordList);
    }
}
