package com.ruoyi.bst.teamUser.service.impl;

import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.mapper.TeamMapper;
import com.ruoyi.bst.teamUser.domain.TeamUser;
import com.ruoyi.bst.teamUser.domain.TeamUserQuery;
import com.ruoyi.bst.teamUser.domain.TeamUserVO;
import com.ruoyi.bst.teamUser.domain.enums.TeamUserStatus;
import com.ruoyi.bst.teamUser.mapper.TeamUserMapper;
import com.ruoyi.bst.teamUser.service.TeamUserService;
import com.ruoyi.bst.teamUser.service.TeamUserValidator;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class TeamUserValidatorImpl implements TeamUserValidator {

    @Autowired
    private TeamUserService teamUserService;
    @Autowired
    private TeamUserMapper teamUserMapper;
    @Autowired
    private TeamMapper teamMapper;

    @Override
    public boolean canJoinTeam(Long userId) {
        TeamUserQuery query = new TeamUserQuery();
        query.setUserId(userId);
        query.setStatus(TeamUserStatus.JOINED.getCode());
        TeamUserVO vo = teamUserService.selectOne(query);
        return vo == null;
    }

    @Override
    public boolean canEdit(Long teamUserId) {
        return canOperate(Arrays.asList(teamUserId));
    }

    @Override
    public boolean kicked(Long teamId, Long userId) {
        TeamUserQuery query = new TeamUserQuery();
        query.setUserId(userId);
        query.setTeamId(teamId);
        query.setStatus(TeamUserStatus.KICKED.getCode());
        TeamUserVO vo = teamUserService.selectOne(query);
        return vo != null;
    }

    // 是否可以操作拼桌队员
    private boolean canOperate(List<Long> teamUserIds) {
        return hasPermission(teamUserIds, StoreStaffPermission.TEAM_USER_EDIT.getCode());
    }

    private boolean hasPermission(List<Long> teamUserIds, String permission) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(teamUserIds)) {
            return true;
        }
        // 查询拼桌用户
        TeamUserQuery query = new TeamUserQuery();
        query.setTeamUserIds(teamUserIds);
        query.setScope(true);
        query.addStorePermission(permission);
        List<Long> teamUserIdList = teamUserMapper.selectIdByQuery(query);
        return new HashSet<>(teamUserIdList).containsAll(teamUserIds);
    }

}
