package com.ruoyi.web.bst;

import com.ruoyi.bst.location.domain.Location;
import com.ruoyi.bst.location.domain.LocationQuery;
import com.ruoyi.bst.location.domain.LocationVO;
import com.ruoyi.bst.location.service.LocationAssembler;
import com.ruoyi.bst.location.service.LocationService;
import com.ruoyi.bst.location.service.LocationValidator;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 存放位置Controller
 *
 * @author ruoyi
 * @date 2025-06-06
 */
@RestController
@RequestMapping("/bst/location")
public class LocationController extends BaseController
{
    @Autowired
    private LocationService locationService;
    @Autowired
    private LocationAssembler locationAssembler;
    @Autowired
    private LocationValidator locationValidator;

    /**
     * 查询存放位置列表
     */
    @PreAuthorize("@ss.hasPermi('bst:location:list')")
    @GetMapping("/list")
    public TableDataInfo list(LocationQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        query.addStorePermission(StoreStaffPermission.LOCATION_VIEW.getCode());
        List<LocationVO> list = locationService.selectLocationList(query);
        locationAssembler.assembleStorageNum(list);
        return getDataTable(list);
    }

    /**
     * 导出存放位置列表
     */
    @PreAuthorize("@ss.hasPermi('bst:location:export')")
    @Log(title = "存放位置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LocationQuery query)
    {
        query.setScope(true);
        List<LocationVO> list = locationService.selectLocationList(query);
        ExcelUtil<LocationVO> util = new ExcelUtil<LocationVO>(LocationVO.class);
        util.exportExcel(response, list, "存放位置数据");
    }

    /**
     * 获取存放位置详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:location:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(locationService.selectLocationById(id,true));
    }

    /**
     * 新增存放位置
     */
    @PreAuthorize("@ss.hasPermi('bst:location:add')")
    @Log(title = "存放位置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class)  Location location)
    {
        return toAjax(locationService.insertLocation(location));
    }

    /**
     * 修改存放位置
     */
    @PreAuthorize("@ss.hasPermi('bst:location:edit')")
    @Log(title = "存放位置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class)  Location location)
    {
        if (!locationValidator.canEdit(location.getId())){
            return AjaxResult.error("您没有权限修改存放位置信息");
        }
        return toAjax(locationService.updateLocation(location));
    }

    /**
     * 删除存放位置
     */
    @PreAuthorize("@ss.hasPermi('bst:location:remove')")
    @Log(title = "存放位置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        if (!locationValidator.canDelete(ids)){
            return AjaxResult.error("您没有权限修改存放位置信息");
        }
        return toAjax(locationService.deleteLocationByIds(ids));
    }
}
