package com.ruoyi.web.bst;

import com.ruoyi.bst.storage.domain.Storage;
import com.ruoyi.bst.storage.domain.StorageQuery;
import com.ruoyi.bst.storage.domain.StorageVO;
import com.ruoyi.bst.storage.domain.dto.StorageDTO;
import com.ruoyi.bst.storage.service.StorageConverter;
import com.ruoyi.bst.storage.service.StorageService;
import com.ruoyi.bst.storage.service.StorageValidator;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;

/**
 * 存酒Controller
 *
 * @author ruoyi
 * @date 2025-06-06
 */
@RestController
@RequestMapping("/bst/storage")
public class StorageController extends BaseController
{
    @Autowired
    private StorageService storageService;
    @Autowired
    private StorageConverter storageConverter;
    @Autowired
    private StorageValidator storageValidator;

    /**
     * 查询存酒列表
     */
    @PreAuthorize("@ss.hasPermi('bst:storage:list')")
    @GetMapping("/list")
    public TableDataInfo list(StorageQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        query.addStorePermission(StoreStaffPermission.STORAGE_VIEW.getCode());
        List<StorageVO> list = storageService.selectStorageList(query);
        return getDataTable(list);
    }

    /**
     * 导出存酒列表
     */
    @PreAuthorize("@ss.hasPermi('bst:storage:export')")
    @Log(title = "存酒", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StorageQuery query)
    {
        query.setScope(true);
        List<StorageVO> list = storageService.selectStorageList(query);
        ExcelUtil<StorageVO> util = new ExcelUtil<StorageVO>(StorageVO.class);
        util.exportExcel(response, list, "存酒数据");
    }

    /**
     * 获取存酒详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:storage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(storageService.selectStorageById(id,true));
    }

    /**
     * 新增存酒
     */
    @PreAuthorize("@ss.hasPermi('bst:storage:add')")
    @Log(title = "存酒", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Storage storage)
    {
        storageConverter.toPoByCreate(storage);
        return toAjax(storageService.insertStorage(storage));
    }

    /**
     * 修改存酒
     */
    @PreAuthorize("@ss.hasPermi('bst:storage:edit')")
    @Log(title = "存酒", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Storage storage)
    {
        if (!storageValidator.canEdit(storage.getId())){
            return AjaxResult.error("您无权限修改当前存酒信息");
        }
        return toAjax(storageService.updateStorage(storage));
    }


    /**
     * 修改存酒
     */
    @PreAuthorize("@ss.hasPermi('bst:storage:getWine')")
    @Log(title = "取酒", businessType = BusinessType.UPDATE)
    @PutMapping("/getWine")
    public AjaxResult getWine(@RequestBody List<StorageDTO> dtoList)
    {
        // 权限相关校验
        List<Long> ids = new ArrayList<>();
        dtoList.forEach(storage->{
            ids.add(storage.getStorageId());
        });
        if (!storageValidator.canEdit(ids)){
            return AjaxResult.error("您无权限修改当前存酒信息");
        }
        return toAjax(storageService.getWine(dtoList));
    }

}
