package com.ruoyi.web.bst;

import com.ruoyi.bst.storageRecord.domain.StorageRecord;
import com.ruoyi.bst.storageRecord.domain.StorageRecordQuery;
import com.ruoyi.bst.storageRecord.domain.StorageRecordVO;
import com.ruoyi.bst.storageRecord.service.StorageRecordService;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 取酒记录Controller
 *
 * @author ruoyi
 * @date 2025-06-06
 */
@RestController
@RequestMapping("/bst/storageRecord")
public class StorageRecordController extends BaseController
{
    @Autowired
    private StorageRecordService storageRecordService;

    /**
     * 查询取酒记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:storageRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(StorageRecordQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        query.addStorePermission(StoreStaffPermission.STORAGE_RECORD_VIEW.getCode());
        List<StorageRecordVO> list = storageRecordService.selectStorageRecordList(query);
        return getDataTable(list);
    }

    /**
     * 导出取酒记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:storageRecord:export')")
    @Log(title = "取酒记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StorageRecordQuery query)
    {
        query.setScope(true);
        List<StorageRecordVO> list = storageRecordService.selectStorageRecordList(query);
        ExcelUtil<StorageRecordVO> util = new ExcelUtil<StorageRecordVO>(StorageRecordVO.class);
        util.exportExcel(response, list, "取酒记录数据");
    }

    /**
     * 获取取酒记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:storageRecord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(storageRecordService.selectStorageRecordById(id,true));
    }

    /**
     * 新增取酒记录
     */
    @PreAuthorize("@ss.hasPermi('bst:storageRecord:add')")
    @Log(title = "取酒记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StorageRecord storageRecord)
    {
        return toAjax(storageRecordService.insertStorageRecord(storageRecord));
    }

    /**
     * 修改取酒记录
     */
    @PreAuthorize("@ss.hasPermi('bst:storageRecord:edit')")
    @Log(title = "取酒记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StorageRecord storageRecord)
    {
        return toAjax(storageRecordService.updateStorageRecord(storageRecord));
    }

    /**
     * 删除取酒记录
     */
    @PreAuthorize("@ss.hasPermi('bst:storageRecord:remove')")
    @Log(title = "取酒记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(storageRecordService.deleteStorageRecordByIds(ids));
    }
}
